#include "popup.hpp"

PopupWindowButton::PopupWindowButton(
		       void (*open)(PopupWindowButton*),
		       int x1, int y1, int x2, int y2,
		       char *mtext1, char *mtext2) :
		       Icon(x1, y1, x2, y2)
{
	open_window = open;
	window = 0;
	text1 = mtext1;
	text2 = mtext2;

	text_color =  BLACK;
	shade_color = BLACK;
	border_color = YELLOW;
	inactive_color = BRIGHT_BLUE;
	active_color =  YELLOW;
	fill_color = inactive_color;
	box = new ShadedBox(x1, y1, x2 - x1, y2 - y1,
					shade_color,
					border_color,
					fill_color);
}

void PopupWindowButton::Display()
{
	box->Display();

	BOX_TYPE title_box;
	title_box.x1 = x1;
	title_box.y1 = y1;
	title_box.x2 = x2;
	title_box.y2 = y2;
	Legend title_legend;
	title_legend.Center(&title_box, text_color,
			    text1, text2);
}


void PopupWindowButton::LeftButtonPressed()
{
	box->Color(active_color);
	Display();
}

void PopupWindowButton::LeftButtonReleased()
{
	box->Color(inactive_color);
	Display();

	// exit if a window is already open
	if (window) return;

	if (open_window)
	  (*open_window)(this);
}


PopupWindowButton::~PopupWindowButton()
{
	delete box;

	// remove the button before the window
	// it might have opened
	CurrentScreen->RemoveItem(this);

	if (window)
	  delete window;
}



PopupWindow::PopupWindow(PopupWindowButton* parent,
			 int x1, int y1, int x2, int y2, char* ptitle) :
			 Icon(x1, y1, x2, y2)
{
	parent_button = parent;
	parent_button->window = this;

	title_color =  BLACK;
	title_backdrop_color =  BRIGHT_CYAN;
	shade_color = BLACK;
	border_color = YELLOW;
	inactive_color = GRAY;
	active_color = WHITE;

	box = new ShadedBox(x1, y1, x2 - x1, y2 - y1,
					shade_color,
					border_color,
					inactive_color);

	exit_button = new PopupWindowExitButton(this, ptitle,
		shade_color,
		border_color,
		inactive_color,
		active_color,
		title_color,
		x1,
		y2 - POPUP_WINDOW_LEGEND_HEIGHT,
		x2, y2);
}

void PopupWindow::Display()
{
	box->Display();
	exit_button->Display();
}


PopupWindow::~PopupWindow()
{
	delete box;
	delete exit_button;

	parent_button->window = 0;

	// remove item from screen list
	// before we repaint the screen.
	// include the shaded areas too.
	CurrentScreen->RemoveItem(this);
	CurrentScreen->ReDraw(x1, y1 - 3, x2 + 3, y2);
}

PopupWindowExitButton::PopupWindowExitButton(PopupWindow* parent,
			     char* title,
			     COLOR_TYPE shade_clr,
			     COLOR_TYPE border_clr,
			     COLOR_TYPE inactive_clr,
			     COLOR_TYPE active_clr,
			     COLOR_TYPE legend_clr,
			     int x1, int y1, int x2, int y2) :
			     Icon(x1, y1, x2, y2)

{
	parent_window = parent;
	strncpy(legend, title, sizeof(legend) );

	shade_color = shade_clr;
	border_color = border_clr;
	fill_color = inactive_color = inactive_clr;
	active_color = active_clr;
	legend_color = legend_clr;

	top_box = new TopShadedBox(x1, y1, x2-x1, y2-y1,
				    shade_color, border_color, fill_color);
}

void PopupWindowExitButton::Display()
{
	top_box->Display();

	// add BOTTOM border lines
	BOX_TYPE bottom_border;
	bottom_border.x1 = x1 + 2;
	bottom_border.y1 = y1;
	bottom_border.x2 = x2 - 4;
	bottom_border.y2 = y1 + 1;
	GraphicsHandler->FillBox(border_color, &bottom_border);

	// display exit button title
	BOX_TYPE title_box;
	title_box.x1 = x1;
	title_box.y1 = y1;
	title_box.x2 = x2;
	title_box.y2 = y2;
	Legend title_legend;
	title_legend.Center(&title_box, legend_color, legend);
}


void PopupWindowExitButton::LeftButtonPressed()
{
	top_box->Color(active_color);
	Display();
}

void PopupWindowExitButton::LeftButtonReleased()
{
	delete parent_window;
}

PopupWindowExitButton::~PopupWindowExitButton()
{
	delete top_box;
}
